==> sime_library-0.5.tar.gz: sime_library-0.5/README.md <==
# Sime library

Sime library - это библиотека для Python, которая предоставляет набор функций для улучшения удобности кода

## Установка

Вы можете установить библиотеку с помощью pip: `pip install sime-library`

## Использование


```python
import sime_library
sime_library.sleep(1)  # Компьюетр спит одну секунду
```
2. `LICENSE`:

MIT License

Авторское право (c) [2023] [Dmitro]

Данная лицензия разрешает лицам, получившим копию данного программного обеспечения и сопутствующей документации (в дальнейшем именуемыми "Программное обеспечение"), безвозмездно использовать Программное обеспечение без ограничений, включая без ограничений право на использование, копирование, изменение, объединение, публикацию, распространение, sublicense и/или продажу копий Программного обеспечения, а также лицам, которым предоставляется данное Программное обеспечение, при соблюдении следующих условий:

Уведомление об авторском праве и данной лицензии должно быть включено во все копии или значительные части Программного обеспечения.

ПРОГРАММНОЕ ОБЕСПЕЧЕНИЕ ПОСТАВЛЯЕТСЯ "КАК ЕСТЬ", БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ, ЯВНЫХ ИЛИ ПОДРАЗУМЕВАЕМЫХ, ВКЛЮЧАЯ, НО НЕ ОГРАНИЧИВАЯСЬ, ГАРАНТИЯМИ КОММЕРЧЕСКОЙ ЦЕННОСТИ, ПРИГОДНОСТИ ДЛЯ ОПРЕДЕЛЕННЫХ ЦЕЛЕЙ И НЕНАРУШЕНИЯ ПРАВ. В НИКАКОМ СЛУЧАЕ АВТОРЫ ИЛИ ПРАВООБЛАДАТЕЛИ НЕ НЕСУТ ОТВЕТСТВЕНОСТИ ПО КАКИМ-ЛИБО ИСКАМ, УБЫТКАМ ИЛИ ДРУГИМ ОТВЕТСТВЕННОСТЯМ, БУДЬ ТО В ДОГОВОРЕ, ВИНЕ ИЛИ ИНЫМ ОБРАЗОМ, ВЫТЕКАЮЩИМ ИЗ ИЛИ СВЯЗАННЫМ С ПРОГРАММНЫМ ОБЕСПЕЧЕНИЕМ ИЛИ ИСПОЛЬЗОВАНИЕМ ПРОГРАММНОГО ОБЕСПЕЧЕНИЯ.

==> sime_library-1.1.tar.gz: sime_library-1.1/README.md <==
# Sime library

Sime library - это библиотека для Python, которая предоставляет набор функций для улучшения удобности кода

## Установка

Вы можете установить библиотеку с помощью pip: `pip install sime-library`

## Использование


Здесь я не могу расписать всё очень подробно но, у меня есть с сайт с полной документацией библиотеки. Ссылка: https://dmitros-organization.gitbook.io/sime_library/
2. `LICENSE`:

MIT License

Авторское право (c) [2023] [Dmitro]

Данная лицензия разрешает лицам, получившим копию данного программного обеспечения и сопутствующей документации (в дальнейшем именуемыми "Программное обеспечение"), безвозмездно использовать Программное обеспечение без ограничений, включая без ограничений право на использование, копирование, изменение, объединение, публикацию, распространение, sublicense и/или продажу копий Программного обеспечения, а также лицам, которым предоставляется данное Программное обеспечение, при соблюдении следующих условий:

Уведомление об авторском праве и данной лицензии должно быть включено во все копии или значительные части Программного обеспечения.

ПРОГРАММНОЕ ОБЕСПЕЧЕНИЕ ПОСТАВЛЯЕТСЯ "КАК ЕСТЬ", БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ, ЯВНЫХ ИЛИ ПОДРАЗУМЕВАЕМЫХ, ВКЛЮЧАЯ, НО НЕ ОГРАНИЧИВАЯСЬ, ГАРАНТИЯМИ КОММЕРЧЕСКОЙ ЦЕННОСТИ, ПРИГОДНОСТИ ДЛЯ ОПРЕДЕЛЕННЫХ ЦЕЛЕЙ И НЕНАРУШЕНИЯ ПРАВ. В НИКАКОМ СЛУЧАЕ АВТОРЫ ИЛИ ПРАВООБЛАДАТЕЛИ НЕ НЕСУТ ОТВЕТСТВЕНОСТИ ПО КАКИМ-ЛИБО ИСКАМ, УБЫТКАМ ИЛИ ДРУГИМ ОТВЕТСТВЕННОСТЯМ, БУДЬ ТО В ДОГОВОРЕ, ВИНЕ ИЛИ ИНЫМ ОБРАЗОМ, ВЫТЕКАЮЩИМ ИЗ ИЛИ СВЯЗАННЫМ С ПРОГРАММНЫМ ОБЕСПЕЧЕНИЕМ ИЛИ ИСПОЛЬЗОВАНИЕМ ПРОГРАММНОГО ОБЕСПЕЧЕНИЯ.
